==> payroll_ver_3.2.1.zip: payroll3/src/jp/mosp/common/action/MosPLogoutAction.java <==
/*
 * MosP - Mind Open Source Project         http://www.mosp.jp/
 * Copyright (C) 1987-2009 MIND Co., Ltd.  http://www.e-mind.co.jp/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
/*
 * MosP - Mind Open Source Project         http://www.mosp.jp/
 * Copyright (C) 1987-2009 MIND Co., Ltd.  http://www.e-mind.co.jp/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
package jp.mosp.common.action;

import jp.mosp.common.MosPAction;
import jp.mosp.common.common.LogUtility;
import jp.mosp.common.common.MospConst;
import jp.mosp.common.common.MospUtility;

public class MosPLogoutAction extends MosPAction {

	/**
	 * RXgN^
	 */
	public MosPLogoutAction() {
		super();
	}

	/**
	 * ANV
	 */
	public void action() throws Exception {
		// ȑ
		if (user != null) {
			deleteExclusive(user.getUserId());
		}
		// ZbV̏
		if (session != null) {
			session.invalidate();
		}
		session = request.getSession(true);
		// R}hyёJڐ̐ݒ
		setNextCmd(getIndexCommand(false));
		setUrl(MospConst.URL_SRV);
		// bZ[W̐ݒ
		request.setAttribute(MospConst.ATT_MESSAGE, MospUtility.getMessage(msg, MospConst.MSG_LOGOUT, ""));
		// Oo
		LogUtility.log(request, 4, MospConst.LOG_MOSPINF, MospConst.LOG_MSG_LOGOUT);
	}

}

==> payroll_ver_3.3.1.zip: payroll3/src/jp/mosp/common/action/MosPLogoutAction.java <==
/*
 * MosP - Mind Open Source Project    http://www.mosp.jp/
 * Copyright (C) MIND Co., Ltd.       http://www.e-mind.co.jp/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
package jp.mosp.common.action;

import jp.mosp.common.MosPAction;
import jp.mosp.common.common.LogUtility;
import jp.mosp.common.common.MospConst;

/**
 * @author yoshida
 *
 */
public class MosPLogoutAction extends MosPAction {
	
	/**
	 * RXgN^
	 */
	public MosPLogoutAction() {
		super();
	}
	
	/**
	 * ANV
	 */
	public void action() throws Exception {
		// ȑ
		if (user != null) {
			deleteExclusive(user.getUserId());
		}
		// ZbV̏
		if (session != null) {
			session.invalidate();
		}
		session = request.getSession(true);
		// R}hyёJڐ̐ݒ
		setNextCmd(getIndexCommand(false));
		setUrl(MospConst.URL_SRV);
		// bZ[W̐ݒ
		setMessage(getMessage(MospConst.MSG_LOGOUT, ""));
		// Oo
		LogUtility.log(request, 4, MospConst.LOG_MOSPINF, MospConst.LOG_MSG_LOGOUT);
	}
	
}
